@@ -1,16 +1,17 @@
-installPackages <- function(x, minCount=sqrt(x[['Count']][1]),
-                                    ...){
+installPackages <- function(x,
+                            minCount = sqrt(x[1, 'Count']),
+                            ...){
 ##
 ## 1.  pkgs needed
 ##
   pkgsum <- attr(x, 'PackageSummary')
   xName <- substring(deparse(substitute(x)), 1, 25)
-  if(is.null(pkgsum))
+  if (is.null(pkgsum))
     stop('not a findFn object;  does not have ',
          'attribute PackageSummary:  ', xName)
-  if(!is.data.frame(x))
+  if (!is.data.frame(x))
     stop('not a findFn object:  is not a data.frame:  ', xName)
-  if(!all(c('Count', 'Package') %in% names(x)))
+  if (!all(c('Count', 'Package') %in% names(x)))
     stop('Must have columns Count & Package:  ', xName)
   sel <- (pkgsum$Count >= minCount)
   toget <- pkgsum$Package[sel]
@@ -22,6 +23,7 @@ installPackages <- function(x, minCount=sqrt(x[['Count']][1]),
 ##
 ## 3.  get not installed
 ##
-  if(length(notInst)>0) install.packages(notInst)
+  if (length(notInst) > 0)
+    install.packages(notInst)
 }
 
